---

slug: /json-formatted-data-types
---

# JSON data types overview

seekdb supports JSON (JavaScript Object Notation) data types that conform to the RFC 7159 standard. You can store semi-structured JSON data and access and modify data in JSON documents.

JSON data types have the following advantages:

* JSON documents stored in JSON columns are automatically validated. Invalid documents will trigger an error.

* JSON documents stored in JSON columns can be converted into a format that is convenient for quick reading and access. When the server needs to read a JSON value stored in binary format, it does not need to parse the value from text.

* Semi-structured encoding is supported, which further reduces storage costs. It allows splitting a JSON data into multiple sub-columns for storage, with each sub-column encoded separately to improve encoding compression and reduce the storage space required for the JSON data. For more information, see [Create a JSON value](200.create-a-json-value-of-syntax.md).

## References

* [JSON functions](https://en.oceanbase.com/docs/common-oceanbase-database-10000000001975908)